@@ -1,4 +1,4 @@
-from dagster._core.utils import check_dagster_package_version
+from dagster._core.libraries import DagsterLibraryRegistry
 
 from .solids import create_shell_command_op, create_shell_script_op, shell_op
 from .utils import (
@@ -7,7 +7,7 @@ from .utils import (
 )
 from .version import __version__
 
-check_dagster_package_version("dagster-shell", __version__)
+DagsterLibraryRegistry.register("dagster-shell", __version__)
 
 __all__ = [
     "create_shell_command_op",
